<?php
namespace SM\Factory;

use Doctrine\ORM\EntityManager;
use SM\Traits\TQuery;

class Sm00006000TipoDeMedidaFactory {
    use TQuery;

    protected $connection;

    protected $entityManager;

    public function __construct(EntityManager $entityManager) {
        $this->connection = $entityManager->getConnection();
        $this->entityManager = $entityManager;
    }
    
    public function getDescTipoMedida() {
        $sql = "SELECT DSTPMEDIDASERV,CDTPMEDIDASERV,IDTPMEDIDASERV,IDATIVO
                FROM FCT_TIPOMEDIDASERV";
        
        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql);
    }

    public function getVariacaoTipoMedida($parametro) {
        $sql = "SELECT VR.NRVARIACAOTPMEDIDA,
                    VR.CDTPMEDIDASERV,
                    VR.CDTPMEDIDAVARIAVEL,
                    TP.DSTPMEDIDASERV,
                    VR.QTMEDIDAINIVARIACAO,
                    VR.QTMEDIDAFIMVARIACAO,
                    VR.VRPERCVARIACAO,
                    VR.NRORG,
                    VR.DTINCLUSAO,
                    VR.DTULTATU,
                    VR.NRORGINCLUSAO,
                    VR.CDOPERINCLUSAO,
                    VR.NRORGULTATU,
                    VR.CDOPERULTATU,
                    VR.IDATIVO
                        FROM FCT_VARIACAOTIPOMEDIDA VR
                        LEFT JOIN FCT_TIPOMEDIDASERV TP
                        ON TP.CDTPMEDIDASERV = VR.CDTPMEDIDASERV
                        WHERE VR.CDTPMEDIDASERV = :CDTPMEDIDASERV
                        ORDER BY VR.CDTPMEDIDAVARIAVEL, VR.QTMEDIDAINIVARIACAO";
                    
        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql,$parametro);
    }

    public function saveTabTipoMedida(array $params) {
        $sql = "INSERT INTO FCT_TIPOMEDIDASERV (
            CDTPMEDIDASERV,         DSTPMEDIDASERV,         IDTPMEDIDASERV,
            NRORG,                  IDATIVO,                DTINCLUSAO,             
            NRORGINCLUSAO,          CDOPERINCLUSAO           
            )
            VALUES(
            :CDTPMEDIDASERV,        :DSTPMEDIDASERV,        :IDTPMEDIDASERV,
            :NRORG,                 :IDATIVO,               SYSDATE,                
            :NRORGINCLUSAO,         :CDOPERINCLUSAO
            )";

        $this->connection->executeStatement($sql, $params);
    }

    public function updateTabTipoMedida($params) {
        $sql = "UPDATE FCT_TIPOMEDIDASERV
                   SET DSTPMEDIDASERV  = :DSTPMEDIDASERV,
                       IDTPMEDIDASERV  = :IDTPMEDIDASERV,
                       NRORG           = :NRORG,
                       IDATIVO         = :IDATIVO,
                       NRORGULTATU     = :NRORG,
                       CDOPERULTATU    = :CDOPERULTATU,
                       DTULTATU        = SYSDATE
                 WHERE CDTPMEDIDASERV = :CDTPMEDIDASERV";

        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }

    public function validaIntervaloVariacao($params) {
        $sql = "SELECT COUNT (*) AS QTD
                  FROM FCT_VARIACAOTIPOMEDIDA
                 WHERE CDTPMEDIDASERV    =  :CDTPMEDIDASERV
                   AND CDTPMEDIDAVARIAVEL  =  :CDTPMEDIDAVARIAVEL
                   AND NRVARIACAOTPMEDIDA  <> :NRVARIACAOTPMEDIDA 
                   AND (QTMEDIDAINIVARIACAO BETWEEN :QTMEDIDAINIVARIACAO AND :QTMEDIDAFIMVARIACAO
                       OR QTMEDIDAFIMVARIACAO BETWEEN :QTMEDIDAINIVARIACAO AND :QTMEDIDAFIMVARIACAO)";

        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }

    public function insertVariacaoTipoMedida(array $params) {
        $sql = "INSERT INTO FCT_VARIACAOTIPOMEDIDA (
                    NRVARIACAOTPMEDIDA,     CDTPMEDIDASERV,         CDTPMEDIDAVARIAVEL,
                    QTMEDIDAINIVARIACAO,    QTMEDIDAFIMVARIACAO,    VRPERCVARIACAO,         
                    NRORG,                  IDATIVO,                DTINCLUSAO,             
                    NRORGINCLUSAO,          CDOPERINCLUSAO           
                )
                VALUES (
                    :NRVARIACAOTPMEDIDA,    :CDTPMEDIDASERV,        :CDTPMEDIDAVARIAVEL,
                    :QTMEDIDAINIVARIACAO,   :QTMEDIDAFIMVARIACAO,   :VRPERCVARIACAO,        
                    :NRORG,                 :IDATIVO,               SYSDATE,                
                    :NRORGINCLUSAO,         :CDOPERINCLUSAO
                )";

        $this->connection->executeStatement($sql, $params);
    }

    public function updateVariacaoTipoMedida($params) {
        $sql = "UPDATE FCT_VARIACAOTIPOMEDIDA
                   SET CDTPMEDIDASERV      = :CDTPMEDIDASERV,
                       CDTPMEDIDAVARIAVEL  = :CDTPMEDIDAVARIAVEL,
                       QTMEDIDAINIVARIACAO = :QTMEDIDAINIVARIACAO,
                       QTMEDIDAFIMVARIACAO = :QTMEDIDAFIMVARIACAO,
                       VRPERCVARIACAO      = :VRPERCVARIACAO,
                       NRORG               = :NRORG,
                       IDATIVO             = :IDATIVO,
                       NRORGINCLUSAO       = :NRORGINCLUSAO,
                       CDOPERINCLUSAO      = :CDOPERINCLUSAO
                 WHERE NRVARIACAOTPMEDIDA = :NRVARIACAOTPMEDIDA";

        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }


    public function deleteVariacaoTipoMedida($params) {
        $sql = "DELETE FROM FCT_VARIACAOTIPOMEDIDA
                WHERE NRVARIACAOTPMEDIDA = :NRVARIACAOTPMEDIDA";

        $this->connection->executeStatement($sql, $params);
    }

    public function deleteTipoMedida($params) {
        $sql = "DELETE FROM FCT_TIPOMEDIDASERV
                WHERE CDTPMEDIDASERV = :CDTPMEDIDASERV";

        $this->connection->executeStatement($sql, $params);
    }
}