<?php
namespace SM\Factory;

use Doctrine\ORM\EntityManager;
use SM\Traits\TQuery;

class Sm00024000ModeloDocumentoFactory {

    use TQuery;

    protected $connection;

    protected $entityManager;

    public function __construct(EntityManager $entityManager) {
        $this->connection = $entityManager->getConnection();
        $this->entityManager = $entityManager;
    }
 
    public function getInformacoesModeloDocumento() {
        $sql = "SELECT NRSEQMODDOCFCT,
                    DSMODELODOCORCA,
                    IDATIVO,
                    IDDOCRENEGOCIACAO,
                    VRTAMANHOLOGO,
                    NRORG
                FROM FCT_MODELODOC
                ORDER BY NRSEQMODDOCFCT DESC";
        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql);  
    }

    public function getTabAnexo($params) {
        $sql = "SELECT DISTINCT MO.NRMODELODOCIDIOMA,
                    MO.NRSEQMODDOCFCT, 
                    MO.CDIDIOM,
                    MO.NMARQUIVO,
                    MO.DSCAMINHOARQ,
                    MO.DSTIPO,
                    MO.VRTAMANHO,
                    MO.IDATIVO,            
                    IDI.NMIDIOMA
                FROM FCT_MODELODOCIDIOMA MO
                LEFT JOIN IDIOMA IDI
                ON MO.CDIDIOM = IDI.CDIDIOM
                WHERE MO.NRSEQMODDOCFCT = :NRSEQMODDOCFCT";
        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql,$params);  
    }

    public function inserirModeloDocumento($parametros) {
        $sql = "INSERT INTO FCT_MODELODOC (NRSEQMODDOCFCT, DSMODELODOCORCA, IDATIVO, IDDOCRENEGOCIACAO, VRTAMANHOLOGO, NRORG, NRORGINCLUSAO, CDOPERINCLUSAO, DTINCLUSAO)
        VALUES (:NRSEQMODDOCFCT, :DSMODELODOCORCA, :IDATIVO, :IDDOCRENEGOCIACAO, :VRTAMANHOLOGO, :NRORG, :NRORGINCLUSAO, :CDOPERINCLUSAO, SYSDATE)";
        $std = $this->connection->prepare($sql);
        $std->execute($parametros);
    }

    public function saveTabModeloDocumento($parametros) {
        $sql = "UPDATE FCT_MODELODOC
                SET DSMODELODOCORCA       = :DSMODELODOCORCA,
                        IDATIVO           = :IDATIVO,
                        IDDOCRENEGOCIACAO = :IDDOCRENEGOCIACAO,
                        VRTAMANHOLOGO     = :VRTAMANHOLOGO,
                        NRORGULTATU       = :NRORGULTATU,
                        CDOPERULTATU      = :CDOPERULTATU,
                        DTULTATU          = SYSDATE
                WHERE NRSEQMODDOCFCT = :NRSEQMODDOCFCT";
        $std = $this->connection->prepare($sql);
        $std->execute($parametros);
    }

    public function valida($params){
        
        $sql = "SELECT COUNT (*) AS QTD 
                FROM FCT_MODELODOCIDIOMA
                WHERE NRSEQMODDOCFCT  = :NRSEQMODDOCFCT
                AND CDIDIOM           = :CDIDIOM
                AND NRMODELODOCIDIOMA <> NVL(:NRMODELODOCIDIOMA, -1)";

        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
    public function inserirModeloDocumentoIdioma($parametros) {
        $sql = "INSERT INTO FCT_MODELODOCIDIOMA (
                    NRMODELODOCIDIOMA,      NRSEQMODDOCFCT,         CDIDIOM,
                    IDATIVO,                NMARQUIVO,              DSCAMINHOARQ,           
                    DSTIPO,                 VRTAMANHO,              NRORG,                  
                    NRORGINCLUSAO,          CDOPERINCLUSAO,         DTINCLUSAO           
                    )
                    VALUES(
                    :NRMODELODOCIDIOMA,     :NRSEQMODDOCFCT,        :CDIDIOM,
                    :IDATIVO,               :NMARQUIVO,             :DSCAMINHOARQ,          
                    :DSTIPO,                :VRTAMANHO,             :NRORG,                 
                    :NRORGINCLUSAO,         :CDOPERINCLUSAO,        SYSDATE
                    )";
        $std = $this->connection->prepare($sql);
        $std->execute($parametros);
    }
    
    public function atualizarModeloDocumentoIdioma($parametros) {
        $sql = "UPDATE FCT_MODELODOCIDIOMA
                SET NRSEQMODDOCFCT = :NRSEQMODDOCFCT,
                        CDIDIOM     = :CDIDIOM,
                        IDATIVO = :IDATIVO,
                        NMARQUIVO = :NMARQUIVO,
                        DSCAMINHOARQ = :DSCAMINHOARQ,
                        DSTIPO = :DSTIPO,
                        VRTAMANHO = :VRTAMANHO,
                        CDOPERULTATU = :CDOPERULTATU,
                        NRORGULTATU = :NRORGULTATU,
                        DTULTATU = SYSDATE
                WHERE NRMODELODOCIDIOMA = :NRMODELODOCIDIOMA";
        $std = $this->connection->prepare($sql);
        $std->execute($parametros);
    }

    public function deletarAnexo($params){
        $sql = "DELETE FROM FCT_MODELODOCIDIOMA
                WHERE NRMODELODOCIDIOMA = :NRMODELODOCIDIOMA";

        $this->connection->executeStatement($sql, $params);
    }

    public function deletarModeloDocumento($parametro) {
        $sql = "DELETE FROM FCT_MODELODOC
                WHERE NRSEQMODDOCFCT = :NRSEQMODDOCFCT";
        $std = $this->connection->prepare($sql);
        $std->execute($parametro);
    }

    
    public function limparAnexoModeloDocumento(array $params) {
        $sql = "UPDATE FCT_MODELODOCIDIOMA
                SET DSCAMINHOARQ = NULL,
                       NMARQUIVO    = NULL,
                       VRTAMANHO    = NULL,
                       DSTIPO       = NULL
                WHERE NRMODELODOCIDIOMA = :NRMODELODOCIDIOMA";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    

    public function getDocumento(array $params, $connection) {
        if($connection) {
            $this->connection = $connection;
        }
        $sql = "SELECT NMARQUIVO,
                  VRTAMANHO,
                  DSCAMINHOARQ,
                  DSTIPO
                FROM FCT_MODELODOCIDIOMA
                WHERE NRMODELODOCIDIOMA = :NRMODELODOCIDIOMA";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
}
?>