import {
    Http, Metadata, Config, IEventParam,
} from '@zeedhi/core';
import {
    DialogService, Form, LoadingService, Modal, ModalService, Select, TextInput, Number, Text, FileInput, Button, Tabs, IGridEvent,
} from '@zeedhi/common';
import { TekGrid } from '@zeedhi/teknisa-components-common';
import { Utilities } from '@/util/Utilities';

export class Sm00024000ModeloDocumentosController {
    private basicModal!: Modal;

    public tekgridVisivel: boolean = true;

    public currentRow: any = {};

    public rowDeleteAnexo: any = {};

    public habilitarBotao = true;

    get textFrame() {
        return this.currentRow.DSMODELODOCORCA;
    }

    get formVisivel() {
        return !this.tekgridVisivel;
    }

    public abrirFrame({ row }: any) {
        this.tekgridVisivel = false;
        this.currentRow = row;
        const tabs = Metadata.getInstance<Tabs>('tabsInformation');
        tabs.activeTab = 0;
        this.carregarTabs();
    }

    public carregarTabs() {
        const tabs = Metadata.getInstance<Tabs>('tabsInformation');
        const tabAtiva = tabs.activeTab;

        if (tabs.tabs[tabAtiva].name === 'tab_modelodocumento') {
            this.carregarDadosAbaModeloDocumento();
        }

        if (tabs.tabs[tabAtiva].name === 'tab_anexos') {
            this.carregarDadosAbaAnexo();
        }
    }

    public carregarDadosAbaModeloDocumento() {
        Metadata.getInstance<TextInput>('DSMODELODOCORCA').value = this.currentRow.DSMODELODOCORCA;
        Metadata.getInstance<Select>('IDATIVO').value = this.currentRow.IDATIVO;
        Metadata.getInstance<Select>('IDDOCRENEGOCIACAO').value = this.currentRow.IDDOCRENEGOCIACAO;
        Metadata.getInstance<Number>('VRTAMANHOLOGO').value = this.currentRow.VRTAMANHOLOGO;
    }

    public carregarDadosAbaAnexo() {
        const nrseqmoddocfct = this.currentRow.NRSEQMODDOCFCT;
        try {
            const grid = Metadata.getInstance<TekGrid>('tab-variacao');
            grid.datasource.setFilter({
                NRSEQMODDOCFCT: nrseqmoddocfct,
            });
        } catch (e) {
            console.error(e);
        }
    }

    public voltarTekGrid() {
        this.tekgridVisivel = true;
    }

    public async exibirModal() {
        this.basicModal = await ModalService.createFromJson('sm_00024_000_modelo_documentos/modal/sm_00024_000_insercao_documento', true);
        this.basicModal.show();
    }

    public fecharModal() {
        this.basicModal.hide();
        this.basicModal?.destroy();
    }

    public async abrirModal() {
        await this.exibirModal();
        Metadata.getInstance<Text>('titleText').text = 'Inserção de Modelo de Documento';
    }

    public async exibirModalDocumento() {
        this.basicModal = await ModalService.createFromJson('sm_00024_000_modelo_documentos/modal/sm_00024_000_insercao_idioma_documento', true);
        this.basicModal.show();
    }

    public fecharModalDocumento() {
        this.basicModal.hide();
        this.basicModal?.destroy();
    }

    public async abrirModalDocumento() {
        await this.exibirModalDocumento();
        Metadata.getInstance<Text>('titleText').text = 'Inserção Documento Por Idioma';
    }

    public async abrirModalEdicaoDocumento({ row }: any) {
        await this.exibirModalDocumento();
        Metadata.getInstance<Text>('titleText').text = 'Edição de Documento Por Idioma';
        Metadata.getInstance<TextInput>('NRMODELODOCIDIOMA').value = row.NRMODELODOCIDIOMA;
        Metadata.getInstance<TextInput>('NRSEQMODDOCFCT').value = row.NRSEQMODDOCFCT;
        Metadata.getInstance<Select>('CDIDIOM').value = row.CDIDIOM;
        Metadata.getInstance<Select>('idativo').value = row.IDATIVO;
        Metadata.getInstance<TextInput>('NMARQUIVO').value = row.NMARQUIVO;
        Metadata.getInstance<TextInput>('DSCAMINHOARQ').value = row.DSCAMINHOARQ;
        Metadata.getInstance<TextInput>('DSTIPO').value = row.DSTIPO;
        Metadata.getInstance<Number>('VRTAMANHO').value = row.VRTAMANHO;

        if (Metadata.getInstance<TextInput>('NMARQUIVO').value != null) {
            Metadata.getInstance<FileInput>('ARQUIVO').isVisible = false;
        } else {
            Metadata.getInstance<FileInput>('ARQUIVO').isVisible = true;
        }
    }

    public showErrorDialogValidacao() {
        DialogService.show({
            name: 'error-dialog-validacao',
            type: 'error',
            title: 'Atenção',
            text: 'Não é possível adicionar outro registro do mesmo idioma para o mesmo modelo de documento',
        });
    }

    public async inserirModeloDocumentoIdioma() {
        const form = Metadata.getInstance<Form>('form_idioma');
        const grid = Metadata.getInstance<TekGrid>('tab-variacao');
        if (Utilities.validateForm(form)) {
            const file = await Utilities.buildArrayToUpload('ARQUIVO');
            LoadingService.show();
            Http.post('/inserirModeloDocumentoIdioma', {
                NRMODELODOCIDIOMA: Metadata.getInstance<TextInput>('NRMODELODOCIDIOMA').value,
                NRSEQMODDOCFCT: Metadata.getInstance<TextInput>('NRSEQMODDOCFCT').value = this.currentRow.NRSEQMODDOCFCT,
                CDIDIOM: Metadata.getInstance<Select>('CDIDIOM').value,
                IDATIVO: Metadata.getInstance<Select>('IDATIVO').value,
                NMARQUIVO: Metadata.getInstance<TextInput>('NMARQUIVO').value,
                DSCAMINHOARQ: Metadata.getInstance<TextInput>('DSCAMINHOARQ').value,
                DSTIPO: Metadata.getInstance<TextInput>('DSTIPO').value,
                VRTAMANHO: Metadata.getInstance<Number>('VRTAMANHO').value,
                ARQUIVO: file,
            }).then(() => {
                this.fecharModalDocumento();
                grid.datasource.get();
                Utilities.showSuccessMessage();
            }).catch((error: any) => {
                if (error.response.data.error === 'EXISTE') {
                    this.showErrorDialogValidacao();
                } else {
                    Utilities.showErrorMessage(error);
                }
            }).finally(() => {
                LoadingService.hide();
            });
        }
    }

    public inserirModeloDocumento() {
        const form = Metadata.getInstance<Form>('form');
        const grid = Metadata.getInstance<TekGrid>('tek-grid-modelo-documento');

        if (Utilities.validateForm(form)) {
            LoadingService.show();
            Http.post('/inserirModeloDocumento', {
                NRSEQMODDOCFCT: Metadata.getInstance<TextInput>('INS-NRSEQMODDOCFCT').value,
                DSMODELODOCORCA: Metadata.getInstance<TextInput>('INS-DSMODELODOCORCA').value,
                IDATIVO: Metadata.getInstance<Select>('INS-IDATIVO').value,
                IDDOCRENEGOCIACAO: Metadata.getInstance<Select>('INS-IDDOCRENEGOCIACAO').value,
                VRTAMANHOLOGO: Metadata.getInstance<Number>('INS-VRTAMANHOLOGO').value,
            }).then(() => {
                this.fecharModal();
                grid.datasource.get();
                Utilities.showSuccessMessage();
            }).catch((error: any) => {
                Utilities.showErrorMessage(error);
            }).finally(() => {
                LoadingService.hide();
            });
        }
    }

    public saveTabModeloDocumento({ event }: IGridEvent) {
        event!.preventDefault();
        const form = Metadata.getInstance<Form>('form-modelo-documento');
        const grid = Metadata.getInstance<TekGrid>('tek-grid-modelo-documento');

        if (Utilities.validateForm(form)) {
            LoadingService.show();
            Http.post('/saveTabModeloDocumento', {
                NRSEQMODDOCFCT: Metadata.getInstance<TextInput>('NRSEQMODDOCFCT').value = this.currentRow.NRSEQMODDOCFCT,
                DSMODELODOCORCA: Metadata.getInstance<TextInput>('DSMODELODOCORCA').value,
                IDATIVO: Metadata.getInstance<Select>('IDATIVO').value,
                IDDOCRENEGOCIACAO: Metadata.getInstance<Select>('IDDOCRENEGOCIACAO').value,
                VRTAMANHOLOGO: Metadata.getInstance<Number>('VRTAMANHOLOGO').value,
            }).then(() => {
                grid.reload();
                grid.datasource.get();
                Utilities.showSuccessMessage();
            }).catch((error: any) => {
                Utilities.showErrorMessage(error);
            }).finally(() => {
                LoadingService.hide();
            });
        }
    }

    public dialogDeletarModeloDocumento({ component, event }: IEventParam<TekGrid>) {
        event?.preventDefault();
        DialogService.show({
            name: 'dialog-deletar-modelo-doc',
            type: 'warning',
            title: 'Atenção',
            text: 'Todos os dados deste(s) modelo(s) de documento(s) serão perdidos. Deseja continuar?',
            buttons: [
                {
                    name: 'NAO',
                    component: 'ZdButton',
                    label: 'Não',
                    outline: true,
                    events: {
                        click: () => {
                            DialogService.hide();
                        },
                    },
                },
                {
                    name: 'SIM',
                    component: 'ZdButton',
                    label: 'Sim',
                    events: {
                        click: () => {
                            this.deletarModeloDocumento(component);
                            DialogService.hide();
                        },
                    },
                },
            ],
        });
    }

    public deletarModeloDocumento(component: TekGrid) {
        const NRS = (component.selectedRows.map((element: any) => element.NRSEQMODDOCFCT));
        LoadingService.show();
        Http.post('/deletarModeloDocumento', {
            NRS,
        }).then(() => {
            component.selectedRows = [];
            component.datasource.get();
            Utilities.showSuccessMessage();
        }).catch((error: any) => {
            Utilities.showErrorMessage(error);
        }).finally(() => {
            LoadingService.hide();
        });
    }

    public dialogDeletarAnexo({ event } : IEventParam<TekGrid>) {
        event?.preventDefault();
        DialogService.show({
            name: 'dialog-deletar-anexo-idioma',
            type: 'warning',
            title: 'Atenção',
            text: 'Deseja realmente excluir todos os registros selecionados? Seu documento anexado será perdido.',
            buttons: [
                {
                    name: 'NAO',
                    component: 'ZdButton',
                    label: 'Não',
                    outline: true,
                    events: {
                        click: () => {
                            DialogService.hide();
                        },
                    },
                },
                {
                    name: 'SIM',
                    component: 'ZdButton',
                    label: 'Sim',
                    events: {
                        click: () => {
                            this.deletarAnexo();
                            DialogService.hide();
                        },
                    },
                },
            ],
        });
    }

    public deletarAnexo() {
        const grid = Metadata.getInstance<TekGrid>('tab-variacao');
        LoadingService.show();
        Http.post('/deletarAnexo', grid.selectedRows).then(() => {
            grid.selectedRows = [];
            grid.cancelEditedRows();
            grid.reload();
            Utilities.showSuccessMessage();
        }).catch((error) => {
            Utilities.showErrorMessage(error);
        }).finally(() => {
            LoadingService.hide();
        });
    }

    public downloadAnexoModeloDocumento({ row }: any) {
        const nrmodelodocidioma = row.NRMODELODOCIDIOMA;
        const nrorg = row.NRORG;
        window.open(`${Config.endPoint}downloadAnexoModeloDocumento?nrorg=${nrorg}&nrmodelodocidioma=${nrmodelodocidioma}`);
    }

    public dialogDeletarAnexoModeloDocumento({ row }: IEventParam<Button>) {
        this.rowDeleteAnexo = row;
        DialogService.show({
            name: 'dialog-deletar-anexo',
            type: 'warning',
            title: 'Atenção',
            text: 'Deseja realmente excluir o documento anexado?',
            buttons: [
                {
                    name: 'NAO',
                    component: 'ZdButton',
                    label: 'Não',
                    outline: true,
                    events: {
                        click: () => {
                            DialogService.hide();
                        },
                    },
                },
                {
                    name: 'SIM',
                    component: 'ZdButton',
                    label: 'Sim',
                    events: {
                        click: () => {
                            this.deletarAnexoModeloDocumento();
                            DialogService.hide();
                        },
                    },
                },
            ],
        });
    }

    public deletarAnexoModeloDocumento() {
        const grid = Metadata.getInstance<TekGrid>('tab-variacao');
        LoadingService.show();
        Http.post('/deletarAnexoModeloDocumento', {
            row: this.rowDeleteAnexo,
        }).then(() => {
            grid.datasource.get();
            Utilities.showSuccessMessage();
        }).catch((error: any) => {
            Utilities.showErrorMessage(error);
        }).finally(() => {
            LoadingService.hide();
        });
    }

    public cliqueCelula({ column }: any) {
        let preventRowClick = false;
        if (column.name === 'DELETARANEXO' || column.name === 'DOWNLOADANEXO') {
            preventRowClick = true;
        }
        return preventRowClick;
    }

    public habilitarBotaoGrid({ row }: any) {
        return (row.NMARQUIVO != null);
    }
}
